@@ -2,7 +2,7 @@ use warnings;
 use strict;
 
 package FCGI::Client;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use Carp;
 use 5.008001;
 
@@ -42,6 +42,10 @@ FCGI::Client is client library for fastcgi protocol.
 
 Tokuhiro Matsuno E<lt>tokuhirom @*(#RJKLFHFSDLJF gmail.comE<gt>
 
+=head1 THANKS TO
+
+peterkeen
+
 =head1 SEE ALSO
 
 L<FCGI>, L<http://www.fastcgi.com/drupal/node/6?q=node/22>
